@@ -23,20 +23,19 @@
 
 // Qt includes
 
-#include <QIcon>
-#include <KLocalizedString>
 #include <KGuiItem>
+#include <KLocalizedString>
 #include <KStandardGuiItem>
+#include <QIcon>
 
+#include "logLine.h"
 #include "logViewWidget.h"
 #include "logViewWidgetItem.h"
-#include "logLine.h"
 
 #include "logging.h"
 
 DetailDialog::DetailDialog(QWidget *parent)
     : QDialog(parent)
-    , logViewWidget(nullptr)
 {
     setupUi(this);
 
@@ -58,7 +57,7 @@ DetailDialog::~DetailDialog()
 
 void DetailDialog::selectionChanged(LogViewWidget *logViewWidget)
 {
-    this->logViewWidget = logViewWidget;
+    mLogViewWidget = logViewWidget;
 
     updateDetails();
 }
@@ -69,8 +68,8 @@ void DetailDialog::updateDetails()
     // logDebug() << "Updating Detail Dialog...";
 
     // Get the current-last item selected
-    LogViewWidgetItem *item = logViewWidget->lastSelectedItem();
-    if (item == nullptr) {
+    LogViewWidgetItem *item = mLogViewWidget->lastSelectedItem();
+    if (!item) {
         logDebug() << "No item found.";
         return;
     }
@@ -81,49 +80,52 @@ void DetailDialog::updateDetails()
 
     message->setText(item->logLine()->logItems().last());
 
-    if (logViewWidget->topLevelItem(logViewWidget->indexOfTopLevelItem(item) - 1) == nullptr)
+    if (!mLogViewWidget->topLevelItem(mLogViewWidget->indexOfTopLevelItem(item) - 1)) {
         previous->setEnabled(false);
-    else
+    } else {
         previous->setEnabled(true);
+    }
 
-    if (logViewWidget->topLevelItem(logViewWidget->indexOfTopLevelItem(item) + 1) == nullptr)
+    if (!mLogViewWidget->topLevelItem(mLogViewWidget->indexOfTopLevelItem(item) + 1)) {
         next->setEnabled(false);
-    else
+    } else {
         next->setEnabled(true);
+    }
 
     /*
     header->adjustSize();
-    this->adjustSize();
+    adjustSize();
     */
 }
 
 void DetailDialog::moveToItem(int direction)
 {
-    if (direction < 0)
+    if (direction < 0) {
         logDebug() << "Go to previous item...";
-    else
+    } else {
         logDebug() << "Go to next item...";
+    }
 
     // Get the current-last item selected
-    LogViewWidgetItem *item = logViewWidget->lastSelectedItem();
-    if (item == nullptr) {
+    LogViewWidgetItem *item = mLogViewWidget->lastSelectedItem();
+    if (!item) {
         logDebug() << "No item found.";
         return;
     }
 
-    QTreeWidgetItem *destinationItem
-        = logViewWidget->topLevelItem(logViewWidget->indexOfTopLevelItem(item) + direction);
-    if (destinationItem == nullptr) {
-        if (direction < 0)
+    QTreeWidgetItem *destinationItem = mLogViewWidget->topLevelItem(mLogViewWidget->indexOfTopLevelItem(item) + direction);
+    if (!destinationItem) {
+        if (direction < 0) {
             logDebug() << "No previous item found.";
-        else
+        } else {
             logDebug() << "No next item found.";
+        }
         return;
     }
 
     item->setSelected(false);
     destinationItem->setSelected(true);
-    logViewWidget->scrollToItem(destinationItem);
+    mLogViewWidget->scrollToItem(destinationItem);
 
     updateDetails();
 }
