@@ -19,7 +19,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef ETAIL_DIALOG_H
+#ifndef DETAIL_DIALOG_H
 #define DETAIL_DIALOG_H
 
 #include <QDialog>
@@ -35,7 +35,7 @@ class DetailDialog : public QDialog, public Ui::DetailDialogBase
 public:
     explicit DetailDialog(QWidget *parent);
 
-    ~DetailDialog();
+    ~DetailDialog() override;
 
 public Q_SLOTS:
     void selectionChanged(LogViewWidget *logViewWidget);
@@ -52,7 +52,7 @@ private:
      */
     void moveToItem(int direction);
 
-    LogViewWidget *logViewWidget;
+    LogViewWidget *mLogViewWidget = nullptr;
 };
 
 #endif //_DETAIL_DIALOG_H
