@@ -25,7 +25,6 @@
 #include <QList>
 #include <QMutex>
 #include <QString>
-#include <QStringList>
 
 #include "globals.h"
 
@@ -36,7 +35,6 @@
 #include "logViewColumns.h"
 
 class LogViewModel;
-class LogFileReader;
 class LogMode;
 
 class Analyzer : public QObject
@@ -52,11 +50,11 @@ public:
 
     explicit Analyzer(LogMode *mode);
 
-    virtual ~Analyzer();
+    ~Analyzer() override;
 
     virtual void watchLogFiles(bool enabled) = 0;
 
-    virtual void setLogFiles(const QList<LogFile> &logFiles) = 0;
+    virtual void setLogFiles(const QVector<LogFile> &logFiles) = 0;
 
     virtual LogViewColumns initColumns() = 0;
 
@@ -82,11 +80,11 @@ Q_SIGNALS:
 protected:
     void informOpeningProgress(int currentPosition, int total);
 
-    bool parsingPaused;
-    LogViewModel *logViewModel;
-    LogMode *logMode;
-    QMutex insertionLocking;
-    long logLineInternalIdGenerator;
+    bool mParsingPaused = false;
+    LogViewModel *mLogViewModel = nullptr;
+    LogMode *const mLogMode;
+    QRecursiveMutex mInsertionLocking;
+    long mLogLineInternalIdGenerator = 0;
 };
 
 #endif
