@@ -23,17 +23,15 @@
 #define LOG_LEVEL_H
 
 #include <QColor>
-#include <QString>
+#include <QIcon>
 #include <QObject>
-
-class LogLevelPrivate;
-
+#include <QString>
 class LogLevel : QObject
 {
 public:
     explicit LogLevel(int id, const QString &name, const QString &icon, const QColor &color, QObject *parent = nullptr);
 
-    virtual ~LogLevel();
+    ~LogLevel() override;
 
     int id() const;
     QString name() const;
@@ -43,7 +41,12 @@ public:
     QIcon icon() const;
 
 private:
-    LogLevelPrivate *const d;
+    int mId;
+    QString mName;
+
+    QColor mColor;
+
+    QIcon mIcon;
 };
 
 #endif
