@@ -26,11 +26,11 @@
 
 #include "globals.h"
 
-#include "logMode.h"
 #include "logFile.h"
+#include "logMode.h"
 
-#include "logViewModel.h"
 #include "logViewColumns.h"
+#include "logViewModel.h"
 
 class View;
 
@@ -43,7 +43,7 @@ class LogManager : public QObject
 public:
     explicit LogManager(View *view);
 
-    ~LogManager();
+    ~LogManager() override;
 
     View *usedView() const;
 
@@ -82,8 +82,7 @@ private Q_SLOTS:
     void loadDroppedUrls(const QList<QUrl> &urls);
 
 private:
-    void internalInitialize(LogMode *mode, const QList<LogFile> &logFiles,
-                            const QVariant &analyzerOptions = QVariant());
+    void internalInitialize(LogMode *mode, const QVector<LogFile> &logFiles, const QVariant &analyzerOptions = QVariant());
 
     void cleanPreviousLogMode();
 
