@@ -22,7 +22,7 @@
 #ifndef KSYSTEMLOG_LOGGING_H
 #define KSYSTEMLOG_LOGGING_H
 
-#include <QLoggingCategory>
+#include "ksystemlog_debug.h"
 
 /**
  * Existing logging functions are :
@@ -35,8 +35,6 @@
  * logDebug() << "Debug message" << list.size();
  */
 
-Q_DECLARE_LOGGING_CATEGORY(KSYSTEMLOG)
-
 /**
  * Colored logging
  */
