@@ -22,9 +22,9 @@
 #ifndef FILE_LIST_HELPER_H
 #define FILE_LIST_HELPER_H
 
+#include <QIcon>
 #include <QUrl>
 #include <QWidget>
-#include <QIcon>
 
 class QAction;
 class QPushButton;
@@ -39,14 +39,14 @@ class FileListHelper : public QObject
 
 public:
     explicit FileListHelper(QWidget *parent);
-    virtual ~FileListHelper();
+    ~FileListHelper() override;
 
     QStringList findPaths(const QList<QUrl> &urls);
     bool isValidFile(const QUrl &url);
     QStringList expandJoker(const QUrl &url);
 
-    QList<QUrl> openUrls();
-    QUrl openUrl(const QString &originPath);
+    QList<QUrl> openUrls() const;
+    QUrl openUrl(const QString &originPath) const;
 
     /**
      * Change the enabled status of the button and of its QActions
@@ -56,15 +56,13 @@ public:
     /**
      * TODO Do this inline (and remove this method)
      */
-    void prepareButton(QPushButton *button, const QIcon &icon, const QObject *receiver, const char *member,
-                       QWidget *fileList);
+    void prepareButton(QPushButton *button, const QIcon &icon, const QObject *receiver, const char *member, QWidget *fileList);
 
     QAction *prepareButtonAndAction(QPushButton *button, const QIcon &icon);
-    QAction *prepareButtonAndAction(QPushButton *button, const QIcon &icon, const QObject *receiver,
-                                    const char *member);
+    QAction *prepareButtonAndAction(QPushButton *button, const QIcon &icon, const QObject *receiver, const char *member);
 
 private:
-    QWidget *parent;
+    QWidget *const mParent = nullptr;
 };
 
 #endif //_FILE_LIST_HELPER_H
