@@ -21,14 +21,13 @@
 
 #include "cronLogMode.h"
 
-
 #include <KLocalizedString>
 
 #include "logging.h"
 
 #include "cronAnalyzer.h"
-#include "cronConfigurationWidget.h"
 #include "cronConfiguration.h"
+#include "cronConfigurationWidget.h"
 #include "cronItemBuilder.h"
 
 CronLogMode::CronLogMode()
@@ -42,12 +41,12 @@ CronLogMode::CronLogMode()
 
     d->action = createDefaultAction();
     d->action->setToolTip(i18n("Display the planned tasks log (Cron log)."));
-    d->action->setWhatsThis(i18n(
-        "Displays the planned tasks log in the current tab. Cron process is a program in charge of launching "
-        "planned tasks on your system, like security checks, or auto-restarting of some services. Use this "
-        "menu to see the recently launched processes."));
+    d->action->setWhatsThis(
+        i18n("Displays the planned tasks log in the current tab. Cron process is a program in charge of launching "
+             "planned tasks on your system, like security checks, or auto-restarting of some services. Use this "
+             "menu to see the recently launched processes."));
 
-    CronConfiguration *cronConfiguration = logModeConfiguration<CronConfiguration *>();
+    auto *cronConfiguration = logModeConfiguration<CronConfiguration *>();
     checkLogFilesPresence(cronConfiguration->cronPaths());
 }
 
@@ -61,8 +60,8 @@ Analyzer *CronLogMode::createAnalyzer(const QVariant &options)
     return new CronAnalyzer(this);
 }
 
-QList<LogFile> CronLogMode::createLogFiles()
+QVector<LogFile> CronLogMode::createLogFiles()
 {
-    CronConfiguration *cronConfiguration = logModeConfiguration<CronConfiguration *>();
+    auto *cronConfiguration = logModeConfiguration<CronConfiguration *>();
     return cronConfiguration->findNoModeLogFiles(cronConfiguration->cronPaths());
 }
