@@ -46,14 +46,13 @@ class CupsPdfLogMode : public LogMode
     Q_OBJECT
 
 public:
-    explicit CupsPdfLogMode(QSharedPointer<CupsConfiguration> &cupsConfiguration,
-                            CupsConfigurationWidget *cupsConfigurationWidget);
+    explicit CupsPdfLogMode(QSharedPointer<CupsConfiguration> &cupsConfiguration, CupsConfigurationWidget *cupsConfigurationWidget);
 
-    ~CupsPdfLogMode();
+    ~CupsPdfLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _CUPS_PDF_LOG_MODE_H
