@@ -21,46 +21,39 @@
  ***************************************************************************/
 
 #include "journaldConfigurationWidget.h"
+#include "globals.h"
 #include "journaldAddressDialog.h"
 #include "journaldConfiguration.h"
-#include "globals.h"
 
 #include <KLocalizedString>
 
 #include <QCheckBox>
 
 JournaldConfigurationWidget::JournaldConfigurationWidget()
-    : LogModeConfigurationWidget(i18n("Journald Log"), QLatin1String(JOURNALD_MODE_ICON),
-                                 i18n("Journald Log"))
+    : LogModeConfigurationWidget(i18n("Journald Log"), QLatin1String(JOURNALD_MODE_ICON), i18n("Journald Log"))
 {
     setupUi(this);
 
     remoteJournalsListWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
-    connect(remoteJournalsListWidget, &QTableWidget::itemSelectionChanged, this,
-            &JournaldConfigurationWidget::updateButtons);
+    connect(remoteJournalsListWidget, &QTableWidget::itemSelectionChanged, this, &JournaldConfigurationWidget::updateButtons);
 
     connect(lastBootOnly, &QCheckBox::stateChanged, this, &JournaldConfigurationWidget::configurationChanged);
     connect(entriesTypeComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &JournaldConfigurationWidget::configurationChanged);
 
     connect(addAddressButton, &QPushButton::clicked, this, &JournaldConfigurationWidget::addRemoteJournal);
-    connect(modifyAddressButton, &QPushButton::clicked, this,
-            &JournaldConfigurationWidget::modifyRemoteJournal);
-    connect(removeAddressButton, &QPushButton::clicked, this,
-            &JournaldConfigurationWidget::removeRemoteJournal);
-    connect(remoteJournalsListWidget, &QTableWidget::cellDoubleClicked, this,
-            &JournaldConfigurationWidget::tableItemClicked);
+    connect(modifyAddressButton, &QPushButton::clicked, this, &JournaldConfigurationWidget::modifyRemoteJournal);
+    connect(removeAddressButton, &QPushButton::clicked, this, &JournaldConfigurationWidget::removeRemoteJournal);
+    connect(remoteJournalsListWidget, &QTableWidget::cellDoubleClicked, this, &JournaldConfigurationWidget::tableItemClicked);
 }
 
 void JournaldConfigurationWidget::saveConfig()
 {
-    JournaldConfiguration *configuration = Globals::instance()
-                                               .findLogMode(QLatin1String(JOURNALD_LOG_MODE_ID))
-                                               ->logModeConfiguration<JournaldConfiguration *>();
+    auto *configuration = Globals::instance().findLogMode(QLatin1String(JOURNALD_LOG_MODE_ID))->logModeConfiguration<JournaldConfiguration *>();
 
     configuration->setDisplayCurrentBootOnly(lastBootOnly->isChecked());
     configuration->setEntriesType((JournaldConfiguration::EntriesType)entriesTypeComboBox->currentIndex());
 
-    QList<JournalAddress> remoteJournals;
+    QVector<JournalAddress> remoteJournals;
     for (int row = 0; row < remoteJournalsListWidget->rowCount(); row++) {
         QTableWidgetItem *addressItem = remoteJournalsListWidget->item(row, 0);
         QTableWidgetItem *portItem = remoteJournalsListWidget->item(row, 1);
@@ -74,14 +67,12 @@ void JournaldConfigurationWidget::saveConfig()
     }
     configuration->setRemoteJournals(remoteJournals);
 
-    emit configSaved();
+    Q_EMIT configSaved();
 }
 
 void JournaldConfigurationWidget::readConfig()
 {
-    JournaldConfiguration *configuration = Globals::instance()
-                                               .findLogMode(QLatin1String(JOURNALD_LOG_MODE_ID))
-                                               ->logModeConfiguration<JournaldConfiguration *>();
+    auto *configuration = Globals::instance().findLogMode(QLatin1String(JOURNALD_LOG_MODE_ID))->logModeConfiguration<JournaldConfiguration *>();
 
     lastBootOnly->setChecked(configuration->displayCurrentBootOnly());
     entriesTypeComboBox->setCurrentIndex(configuration->entriesType());
@@ -91,16 +82,15 @@ void JournaldConfigurationWidget::readConfig()
         remoteJournalsListWidget->removeRow(0);
     }
 
-    QList<JournalAddress> remoteJournals = configuration->remoteJournals();
+    const QVector<JournalAddress> remoteJournals = configuration->remoteJournals();
     for (const JournalAddress &addressInfo : remoteJournals) {
-        if (haveJournalAddress(addressInfo.address, QString::number(addressInfo.port), addressInfo.https))
+        if (haveJournalAddress(addressInfo.address, QString::number(addressInfo.port), addressInfo.https)) {
             continue;
+        }
         remoteJournalsListWidget->insertRow(remoteJournalsListWidget->rowCount());
-        remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 0,
-                                          new QTableWidgetItem(addressInfo.address));
-        remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 1,
-                                          new QTableWidgetItem(QString::number(addressInfo.port)));
-        QTableWidgetItem *item = new QTableWidgetItem(i18n("Enabled"));
+        remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 0, new QTableWidgetItem(addressInfo.address));
+        remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 1, new QTableWidgetItem(QString::number(addressInfo.port)));
+        auto item = new QTableWidgetItem(i18n("Enabled"));
         item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
         item->setCheckState(addressInfo.https ? Qt::Checked : Qt::Unchecked);
         remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 2, item);
@@ -114,8 +104,8 @@ void JournaldConfigurationWidget::defaultConfig()
 
 void JournaldConfigurationWidget::updateButtons()
 {
-    auto selectedItems = remoteJournalsListWidget->selectedItems();
-    bool haveItems = !selectedItems.empty();
+    const auto selectedItems = remoteJournalsListWidget->selectedItems();
+    const bool haveItems = !selectedItems.empty();
     modifyAddressButton->setEnabled(haveItems);
     removeAddressButton->setEnabled(haveItems);
 }
@@ -124,17 +114,15 @@ void JournaldConfigurationWidget::addRemoteJournal()
 {
     JournaldAddressDialog dialog(this, i18n("Add remote journal"));
     if (dialog.exec() == QDialog::Accepted) {
-        QString address = dialog.address();
-        QString port = dialog.port();
-        bool httpsEnabled = dialog.httpsEnabled();
+        const QString address = dialog.address();
+        const QString port = dialog.port();
+        const bool httpsEnabled = dialog.httpsEnabled();
 
         if (!haveJournalAddress(address, port, httpsEnabled)) {
             remoteJournalsListWidget->insertRow(remoteJournalsListWidget->rowCount());
-            remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 0,
-                                              new QTableWidgetItem(address));
-            remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 1,
-                                              new QTableWidgetItem(port));
-            QTableWidgetItem *item = new QTableWidgetItem(i18n("Enabled"));
+            remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 0, new QTableWidgetItem(address));
+            remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 1, new QTableWidgetItem(port));
+            auto item = new QTableWidgetItem(i18n("Enabled"));
             item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
             item->setCheckState(dialog.httpsEnabled() ? Qt::Checked : Qt::Unchecked);
             remoteJournalsListWidget->setItem(remoteJournalsListWidget->rowCount() - 1, 2, item);
@@ -158,8 +146,7 @@ void JournaldConfigurationWidget::tableItemClicked(int row)
     QTableWidgetItem *portItem = remoteJournalsListWidget->item(row, 1);
     QTableWidgetItem *httpsItem = remoteJournalsListWidget->item(row, 2);
     bool httpsEnabled = (Qt::Checked == httpsItem->checkState());
-    JournaldAddressDialog dialog(this, i18n("Modify remote journal"), addressItem->text(), portItem->text(),
-                                 httpsEnabled);
+    JournaldAddressDialog dialog(this, i18n("Modify remote journal"), addressItem->text(), portItem->text(), httpsEnabled);
     if (dialog.exec() == QDialog::Accepted) {
         QString address = dialog.address();
         QString port = dialog.port();
@@ -179,8 +166,9 @@ bool JournaldConfigurationWidget::haveJournalAddress(const QString &address, con
         QTableWidgetItem *portItem = remoteJournalsListWidget->item(row, 1);
         QTableWidgetItem *httpsItem = remoteJournalsListWidget->item(row, 2);
         bool https = (Qt::Checked == httpsItem->checkState());
-        if ((addressItem->text() == address) && (portItem->text() == port) && (https == httpsEnabled))
+        if ((addressItem->text() == address) && (portItem->text() == port) && (https == httpsEnabled)) {
             return true;
+        }
     }
     return false;
 }
