@@ -46,11 +46,11 @@ class KernelLogMode : public LogMode
 public:
     explicit KernelLogMode();
 
-    ~KernelLogMode();
+    ~KernelLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _KERNEL_LOG_MODE_H
