@@ -44,11 +44,11 @@ class PostfixLogMode : public LogMode
 public:
     explicit PostfixLogMode();
 
-    ~PostfixLogMode();
+    ~PostfixLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _POSTFIX_LOG_MODE_H
