@@ -21,15 +21,14 @@
 
 #include "xsessionLogMode.h"
 
-
 #include <KLocalizedString>
 
 #include "logging.h"
 
 #include "xsessionAnalyzer.h"
-#include "xsessionItemBuilder.h"
-#include "xsessionConfigurationWidget.h"
 #include "xsessionConfiguration.h"
+#include "xsessionConfigurationWidget.h"
+#include "xsessionItemBuilder.h"
 
 XSessionLogMode::XSessionLogMode()
     : LogMode(QStringLiteral(X_SESSION_LOG_MODE_ID), i18n("X Session Log"), QStringLiteral(X_SESSION_MODE_ICON))
@@ -42,12 +41,12 @@ XSessionLogMode::XSessionLogMode()
 
     d->action = createDefaultAction();
     d->action->setToolTip(i18n("Display the X Session log."));
-    d->action->setWhatsThis(i18n(
-        "Displays the X Session log in the current tab. X Session log is the place where graphical programs "
-        "write their output. See this log if you want to know why a program has crashed, or why your desktop "
-        "environment (Plasma, Gnome, Unity, Xfce, LXQt, ...) has not started."));
+    d->action->setWhatsThis(
+        i18n("Displays the X Session log in the current tab. X Session log is the place where graphical programs "
+             "write their output. See this log if you want to know why a program has crashed, or why your desktop "
+             "environment (Plasma, Gnome, Unity, Xfce, LXQt, ...) has not started."));
 
-    XSessionConfiguration *configuration = logModeConfiguration<XSessionConfiguration *>();
+    auto *configuration = logModeConfiguration<XSessionConfiguration *>();
     checkLogFilesPresence(QStringList() << configuration->xsessionPath());
 }
 
@@ -61,13 +60,10 @@ Analyzer *XSessionLogMode::createAnalyzer(const QVariant &options)
     return new XSessionAnalyzer(this);
 }
 
-QList<LogFile> XSessionLogMode::createLogFiles()
+QVector<LogFile> XSessionLogMode::createLogFiles()
 {
-    XSessionConfiguration *configuration = Globals::instance()
-                                               .findLogMode(QStringLiteral(X_SESSION_LOG_MODE_ID))
-                                               ->logModeConfiguration<XSessionConfiguration *>();
+    auto *configuration = Globals::instance().findLogMode(QStringLiteral(X_SESSION_LOG_MODE_ID))->logModeConfiguration<XSessionConfiguration *>();
 
-    QList<LogFile> logFiles;
-    logFiles.append(configuration->findGenericLogFile(configuration->xsessionPath()));
+    const QVector<LogFile> logFiles{configuration->findGenericLogFile(configuration->xsessionPath())};
     return logFiles;
 }
