@@ -22,8 +22,8 @@
 #ifndef TAB_LOG_VIEWS_WIDGET_H
 #define TAB_LOG_VIEWS_WIDGET_H
 
-#include <QTabWidget>
 #include <QList>
+#include <QTabWidget>
 #include <QVariant>
 
 class QString;
@@ -33,8 +33,7 @@ class LogManager;
 class TabLogManager;
 class View;
 class LogMode;
-
-class TabLogViewsWidgetPrivate;
+class QMenu;
 
 class TabLogViewsWidget : public QTabWidget
 {
@@ -43,11 +42,11 @@ class TabLogViewsWidget : public QTabWidget
 public:
     explicit TabLogViewsWidget(QWidget *parent = nullptr);
 
-    virtual ~TabLogViewsWidget();
+    ~TabLogViewsWidget() override;
 
-    QList<LogManager *> logManagers();
+    QList<LogManager *> logManagers() const;
 
-    LogManager *activeLogManager();
+    LogManager *activeLogManager() const;
 
     void load(LogMode *logMode, LogManager *manager, const QVariant &analyzerOptions = QVariant());
 
@@ -78,6 +77,7 @@ public Q_SLOTS:
     void copyToClipboardCurrentView();
     void sendMailCurrentView();
     void printSelectionCurrentView();
+    void printPreviewSelectionCurrentView();
 
 private Q_SLOTS:
     void changeTab(View *view, const QIcon &icon, const QString &label);
@@ -89,8 +89,6 @@ private Q_SLOTS:
     void showContextMenu(QWidget *tab, const QPoint &cursorPosition);
 
 Q_SIGNALS:
-    void tabCreationRequested();
-    void tabClosingRequested();
 
     void logManagerCreated(LogManager *manager);
 
@@ -103,14 +101,15 @@ private:
 
     LogManager *findRelatedLogManager(View *view);
 
-    QIcon logModeIcon(LogMode *icon);
+    QIcon logModeIcon(LogMode *icon) const;
 
-    TabLogManager *activeTabLogManager();
-    TabLogManager *findRelatedTabLogManager(View *view);
+    TabLogManager *activeTabLogManager() const;
+    TabLogManager *findRelatedTabLogManager(View *view) const;
 
     void prepareContextMenu(bool onTab);
+    QList<TabLogManager *> mTabLogManagers;
 
-    TabLogViewsWidgetPrivate *const d;
+    QMenu *mContextMenu = nullptr;
 };
 
 #endif // _TAB_LOG_VIEWS_WIDGET_H
